package speed

  1. Overview
  2. Docs

Source file Speed_metadata.ml

1
2
3
4
5
6
7
type t = ..

module List = struct
  (* This function mostly exists for the purpose of the ppx rewriter, making
     it generate code that depends only on this library *)
  let find_map = Base.List.find_map
end